/* -*- Mode:C++; c++-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Marco Guastella alias Vasta 
 * Web page:<www.ragnu.it> 
 * Email:<vasta@ragnu.it>
 * Date last update: 30/11/2024
*/
 
#ifndef VAMPIRIA_PY_JRP_EVENTJRP_H

#define VAMPIRIA_PY_JRP_EVENTJRP_H 1

//! Internal usage
class PyJrpCommon:public jrp::JrpCommon
{
    public:
        PyJrpCommon();
        ~PyJrpCommon();
    
        pylib::PyCall pyrequestcb_;
        pylib::PyCall pyrequesterrcb_;
        pylib::PyCall pypushcb_;
        pylib::PyCall pyresponsecb_;
        pylib::PyCall pykillcb_;
        pylib::PyCall pyclosecb_;
        
        pylib::PyCall pybroadcastcb_;
};

#endif

